# Function reference {.doc .doc-index}

## Aligner

Aligner class of the brdr package.

| | |
| --- | --- |
| [Aligner](Aligner.qmd#brdr.aligner.Aligner) | Compares and aligns thematic geospatial data against a set of reference data. |
| [AlignerResult](AlignerResult.qmd#brdr.aligner.AlignerResult) | Stores and processes the results from the alignment operation. |

## AlignerFeatures

Classes for the thematic and reference data to be used by the Aligner

| | |
| --- | --- |
| [AlignerFeatureCollection](AlignerFeatureCollection.qmd#brdr.feature_data.AlignerFeatureCollection) | A collection of AlignerFeature objects with spatial indexing and utility properties. |
| [AlignerFeature](AlignerFeature.qmd#brdr.feature_data.AlignerFeature) | A container for a single thematic or reference feature within the aligner. |

## Loaders

Loaders to load data

| | |
| --- | --- |
| [Loader](Loader.qmd#brdr.loader.Loader) | Abstract base class for all data loaders. |
| [DictLoader](DictLoader.qmd#brdr.loader.DictLoader) | Loader that accepts data directly from Python dictionaries. |
| [GeoJsonLoader](GeoJsonLoader.qmd#brdr.loader.GeoJsonLoader) | Base class for loaders dealing with GeoJSON-formatted data. |
| [GeoJsonFileLoader](GeoJsonFileLoader.qmd#brdr.loader.GeoJsonFileLoader) | Loads GeoJSON data from a local file system. |
| [GeoJsonUrlLoader](GeoJsonUrlLoader.qmd#brdr.loader.GeoJsonUrlLoader) | Loads GeoJSON data from a remote URL via HTTP GET. |
| [OGCFeatureAPIReferenceLoader](OGCFeatureAPIReferenceLoader.qmd#brdr.loader.OGCFeatureAPIReferenceLoader) | Loader for OGC API - Features services. |
| [WFSReferenceLoader](WFSReferenceLoader.qmd#brdr.loader.WFSReferenceLoader) | Loader for OGC Web Feature Service (WFS) version 2.0.0. |

## Processors

Processor algorithms

| | |
| --- | --- |
| [BaseProcessor](BaseProcessor.qmd#brdr.processor.BaseProcessor) | Abstract base class for geometric alignment processors. |
| [AlignerGeometryProcessor](AlignerGeometryProcessor.qmd#brdr.processor.AlignerGeometryProcessor) | Processor responsible for aligning thematic geometries to reference data. |
| [DieussaertGeometryProcessor](DieussaertGeometryProcessor.qmd#brdr.processor.DieussaertGeometryProcessor) | Processor implementing the Dieussaert area-based alignment algorithm. |
| [NetworkGeometryProcessor](NetworkGeometryProcessor.qmd#brdr.processor.NetworkGeometryProcessor) | Processor that aligns geometries based on a linear network. |
| [SnapGeometryProcessor](SnapGeometryProcessor.qmd#brdr.processor.SnapGeometryProcessor) | Processor that aligns geometries by snapping them to the reference data. |
| [TopologyProcessor](TopologyProcessor.qmd#brdr.processor.TopologyProcessor) | Processor that aligns geometries while preserving topological relationships. |

## Enumerators

Enums used in the brdr package.

| | |
| --- | --- |
| [FullReferenceStrategy](FullReferenceStrategy.qmd#brdr.enums.FullReferenceStrategy) | Strategy for handling reference data coverage. |
| [AlignerResultType](AlignerResultType.qmd#brdr.enums.AlignerResultType) | Format of the output dictionary. |
| [OpenDomainStrategy](OpenDomainStrategy.qmd#brdr.enums.OpenDomainStrategy) | Strategies for processing thematic areas not covered by reference data. |
| [DiffMetric](DiffMetric.qmd#brdr.enums.DiffMetric) | Metrics to quantify the change between thematic and reference data. |
| [ProcessRemark](ProcessRemark.qmd#brdr.enums.ProcessRemark) | Status remarks added to processed features for auditing and debugging. |
| [Evaluation](Evaluation.qmd#brdr.enums.Evaluation) | Classification of the alignment quality and reliability. |
| [SnapStrategy](SnapStrategy.qmd#brdr.enums.SnapStrategy) | Geometric priority during snapping. |
| [PredictionStrategy](PredictionStrategy.qmd#brdr.enums.PredictionStrategy) | Determines which prediction is selected as the primary result. |
| [ProcessorID](ProcessorID.qmd#brdr.enums.ProcessorID) | Unique identifiers for the available alignment algorithms. |

## Typings

Typings used in 'brdr'

| | |
| --- | --- |
| [ProcessResult](ProcessResult.qmd#brdr.typings.ProcessResult) | A dictionary structure representing the output of a geometric alignment process. |

## Configs

Configs used in 'brdr' Aligner & Processor

| | |
| --- | --- |
| [ProcessorConfig](ProcessorConfig.qmd#brdr.configs.ProcessorConfig) | Configuration for the geometric preprocessing of polygons in the brdr pipeline. |
| [AlignerConfig](AlignerConfig.qmd#brdr.configs.AlignerConfig) | Configuration for the alignment and correction of spatial boundaries. |

## GRB (Flanders-specific)

GRB (Flanders-specific) classes,methods, enumerators,...

| | |
| --- | --- |
| [loader.GRBActualLoader](loader.GRBActualLoader.qmd#brdr.be.grb.loader.GRBActualLoader) | Loader for the most recent version of GRB (Grootschalig Referentie Bestand). |
| [loader.GRBFiscalParcelLoader](loader.GRBFiscalParcelLoader.qmd#brdr.be.grb.loader.GRBFiscalParcelLoader) | Loader for fiscal parcel data (Adpf) for a specific year. |
| [loader.GRBSpecificDateParcelLoader](loader.GRBSpecificDateParcelLoader.qmd#brdr.be.grb.loader.GRBSpecificDateParcelLoader) | Loader for GRB parcel situations on a specific historical date. |
| [grb.update_featurecollection_to_actual_grb](grb.update_featurecollection_to_actual_grb.qmd#brdr.be.grb.grb.update_featurecollection_to_actual_grb) | Update a thematic feature collection to the most recent version of the GRB. |
| [utils.is_grb_changed](utils.is_grb_changed.qmd#brdr.be.grb.utils.is_grb_changed) |    checks if a geometry is possibly affected by changes in the reference layer |
| [utils.get_affected_ids_by_grb_change](utils.get_affected_ids_by_grb_change.qmd#brdr.be.grb.utils.get_affected_ids_by_grb_change) | Get a list of affected IDs by GRB-changes in a |
| [enums.GRBType](enums.GRBType.qmd#brdr.be.grb.enums.GRBType) |  |

## OSM

OpenStreetMap (OSM) classes,methods, enumerators,...

| | |
| --- | --- |
| [loader.OSMLoader](loader.OSMLoader.qmd#brdr.osm.loader.OSMLoader) | Loader for OpenStreetMap (OSM) features based on specific tags. |

## Visualization-functions (optional by pip install brdr[viz])

OpenStreetMap (OSM) classes,methods, enumerators,...

| | |
| --- | --- |
| [show_map](show_map.qmd#brdr.viz.show_map) | Display a grid of maps showing alignment results across different distances. |
| [plot_difference_by_relevant_distance](plot_difference_by_relevant_distance.qmd#brdr.viz.plot_difference_by_relevant_distance) | Plot geometric differences across multiple features as a line graph. |
| [animated_map](animated_map.qmd#brdr.viz.animated_map) | Create a synchronized animation of map changes and area statistics. |
| [print_observation_of_aligner_results](print_observation_of_aligner_results.qmd#brdr.viz.print_observation_of_aligner_results) | Print a detailed comparison analysis for alignment results. |